@@ -109,7 +109,7 @@ def add_autosummary(self):
 	Add the :rst:dir:`autosummary` table of this documenter.
 	"""
 
-	if not self.options.autosummary:
+	if not self.options.get("autosummary", False):
 		return
 
 	content = StringList()
@@ -118,7 +118,7 @@ def add_autosummary(self):
 	grouped_documenters = self.get_grouped_documenters()
 
 	for section, documenters in grouped_documenters.items():
-		if not self.options.autosummary_no_titles:
+		if not self.options.get("autosummary_no_titles", False):
 			content.append(f"**{section}:**")
 
 		content.blankline(ensure_single=True)
@@ -129,7 +129,7 @@ def add_autosummary(self):
 		member_order = get_first_matching(
 				lambda x: x != "groupwise",
 				[
-						self.options.member_order,
+						self.options.get("member_order", ''),
 						self.env.config.autodocsumm_member_order,
 						self.env.config.autodoc_member_order,
 						],
